@@ -130,7 +130,8 @@ class Services_JSON
     *                                   bubble up with an error, so all return values
     *                                   from encode() should be checked with isError()
     */
-    function Services_JSON($use = 0)
+    //function Services_JSON($use = 0)
+	function __construct($use = 0)
     {
         $this->use = $use;
     }
@@ -780,7 +781,9 @@ if (class_exists('PEAR_Error')) {
 
     class Services_JSON_Error extends PEAR_Error
     {
-        function Services_JSON_Error($message = 'unknown error', $code = null,
+//        function Services_JSON_Error($message = 'unknown error', $code = null,
+//                                     $mode = null, $options = null, $userinfo = null)
+        function __construct($message = 'unknown error', $code = null,
                                      $mode = null, $options = null, $userinfo = null)
         {
             parent::PEAR_Error($message, $code, $mode, $options, $userinfo);
@@ -794,7 +797,9 @@ if (class_exists('PEAR_Error')) {
      */
     class Services_JSON_Error
     {
-        function Services_JSON_Error($message = 'unknown error', $code = null,
+//        function Services_JSON_Error($message = 'unknown error', $code = null,
+//                                     $mode = null, $options = null, $userinfo = null)
+        function __construct($message = 'unknown error', $code = null,
                                      $mode = null, $options = null, $userinfo = null)
         {
 
