@@ -7,7 +7,7 @@
 -- *
 -- * @package    Magic3 Framework
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
--- * @copyright  Copyright 2006-2015 Magic3 Project.
+-- * @copyright  Copyright 2006-2018 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 -- * @version    SVN: $Id$
 -- * @link       http://www.magic3.org
@@ -67,40 +67,49 @@ INSERT INTO wiki_config
 
 -- ブログ設定マスター
 INSERT INTO blog_config
-(bg_id,                     bg_value,    bg_name,                              bg_index) VALUES
-('receive_comment',         '0',         'コメントの受け付け',                 1),
-('receive_trackback',       '0',         'トラックバックの受け付け',           2),
-('entry_view_count',        '10',        '記事表示数',                         3),
-('entry_view_order',        '1',         '記事表示順',                         4),
-('comment_max_length',      '300',       'コメント最大文字数',                 5),
-('comment_count',           '100',       '1投稿記事のコメント最大数',          6),
-('comment_open_time',       '30',        'コメント投稿可能期間(日)',           7),
-('use_multi_blog',          '0',         'マルチブログを使用',                 8),
-('multi_blog_top_content',  '',          'マルチブログのトップ画面コンテンツ', 9),
-('category_count',          '2',         '記事に設定可能なカテゴリ数',         10),
-('thumb_type',              's=80c.jpg;mw=160x120c.jpg;l=200c.jpg', '記事サムネールタイプ定義', 0),
-('entry_default_image',     '0_72c.jpg;0_80c.jpg;0_200c.jpg',       '記事デフォルト画像', 0),
-('comment_user_limited',      '0',       'コメントのユーザ制限',                 0),
-('layout_entry_single',   '<small>[#CT_AUTHOR#] [#CT_DATE#] [#CT_TIME#] [#BLOG_LINK#]</small>[#BODY#][#CATEGORY#][#LINKS#]', 'コンテンツレイアウト(記事詳細)',               0),
-('layout_entry_list',   '[#TITLE#]<small>[#CT_AUTHOR#] [#CT_DATE#] [#CT_TIME#] [#BLOG_LINK#]</small>[#BODY#][#CATEGORY#][#COMMENT_LINK#]', 'コンテンツレイアウト(記事一覧)',               0),
-('layout_comment_list',   '[#AVATAR#]<dl><dt>[#TITLE#] <small>[#CM_AUTHOR#] [#CM_DATE#] [#CM_TIME#] [#URL#]</small></dt><dd>[#BODY#]</dd></dl>', 'コンテンツレイアウト(コメント一覧)',               0),
-('output_head',      '0', 'HTMLヘッダ出力', 0),
-('head_view_detail', '<meta property="og:type" content="article" /><meta property="og:title" content="[#CT_TITLE#]" /><meta property="og:url" content="[#CT_URL#]" /><meta property="og:image" content="[#CT_IMAGE#]" /><meta property="og:description" content="[#CT_DESCRIPTION#]" /><meta property="og:site_name" content="[#SITE_NAME#]" />', 'HTMLヘッダ(詳細表示)',               0),
-('m:entry_view_count',      '3',         '記事表示数(携帯)',                   11),
-('m:entry_view_order',      '1',         '記事表示順(携帯)',                   12),
-('m:title_color',           '',         'タイトルの背景色',                    13),
-('s:entry_view_count',        '10',        '記事表示数',                         100),
-('s:entry_view_order',        '1',         '記事表示順',                         101),
-('s:top_content',  '',          'トップ画面コンテンツ', 102),
-('s:auto_resize_image_max_size',  '280',      '画像の自動変換最大サイズ',           103),
-('s:jquery_view_style',       '1',      'jQueryMobile表示スタイル',           104),
-('s:use_title_list_image',       '1',      'タイトルリスト画像を使用',           105),
-('s:title_list_image',       '',      'タイトルリスト画像',           106),
-('s:layout_entry_single',   '<small>[#CT_AUTHOR#] [#CT_DATE#] [#CT_TIME#] [#BLOG_LINK#]</small>[#BODY#][#CATEGORY#][#LINKS#]', 'コンテンツレイアウト(記事詳細)',               100),
-('s:layout_entry_list',   '[#TITLE#]<small>[#CT_AUTHOR#] [#CT_DATE#] [#CT_TIME#] [#BLOG_LINK#]</small>[#BODY#][#CATEGORY#][#COMMENT_LINK#]', 'コンテンツレイアウト(記事一覧)',               100),
-('s:layout_comment_list', '[#AVATAR#]<dl><dt>[#TITLE#] <small>[#CM_AUTHOR#] [#CM_DATE#] [#CM_TIME#] [#URL#]</small></dt><dd>[#BODY#]</dd></dl>', 'コンテンツレイアウト(コメント一覧)',               0),
-('s:output_head',      '0', 'HTMLヘッダ出力', 100),
-('s:head_view_detail', '<meta property="og:type" content="article" /><meta property="og:title" content="[#CT_TITLE#]" /><meta property="og:url" content="[#CT_URL#]" /><meta property="og:image" content="[#CT_IMAGE#]" /><meta property="og:description" content="[#CT_DESCRIPTION#]" /><meta property="og:site_name" content="[#SITE_NAME#]" />', 'HTMLヘッダ(詳細表示)',               100);
+(bg_id,                     bg_value,    bg_name) VALUES
+('receive_comment',         '0',         'コメントの受け付け'),
+('receive_trackback',       '0',         'トラックバックの受け付け'),
+('entry_view_count',        '10',        '記事表示数'),
+('entry_view_order',        '1',         '記事表示順'),
+('comment_max_length',      '300',       'コメント最大文字数'),
+('comment_count',           '100',       '1投稿記事のコメント最大数'),
+('comment_open_time',       '30',        'コメント投稿可能期間(日)'),
+('use_multi_blog',          '0',         'マルチブログを使用'),
+('multi_blog_top_content',  '',          'マルチブログのトップ画面コンテンツ'),
+('category_count',          '2',         '記事に設定可能なカテゴリ数'),
+('readmore_label',          'もっと読む',         '「もっと読む」ボタンラベル'),
+('entry_list_disp_type',         '0',         '記事一覧の表示タイプ'),
+('show_entry_list_image',         '1',         '記事一覧に画像を表示するかどうか'),
+('entry_list_image_type',         '80c.jpg',         '一覧の画像タイプ'),
+('show_prev_next_entry_link',    '1', '前後記事リンクを表示するかどうか'),
+('prev_next_entry_link_pos',     '1', '前後記事リンク表示位置'),
+('show_entry_author',            '1', '投稿者を表示するかどうか'),
+('show_entry_regist_dt',         '1', '投稿日時を表示するかどうか'),
+('show_entry_view_count',        '0', '閲覧数を表示するかどうか'),
+('thumb_type',              's=80c.jpg;mw=160x120c.jpg;l=200c.jpg', '記事サムネールタイプ定義'),
+('entry_default_image',     '0_72c.jpg;0_80c.jpg;0_200c.jpg',       '記事デフォルト画像'),
+('comment_user_limited',      '0',       'コメントのユーザ制限'),
+('layout_entry_single',   '<small>[#CT_AUTHOR#] [#CT_DATE#] [#CT_TIME#] [#BLOG_LINK#]</small>[#BODY#][#CATEGORY#][#LINKS#]', 'コンテンツレイアウト(記事詳細)'),
+('layout_entry_list',   '<small>[#CT_AUTHOR#] [#CT_DATE#] [#CT_TIME#] [#BLOG_LINK#]</small>[#BODY#][#CATEGORY#][#COMMENT_LINK#]', 'コンテンツレイアウト(記事一覧)'),
+('layout_comment_list',   '[#AVATAR#]<dl><dt>[#TITLE#] <small>[#CM_AUTHOR#] [#CM_DATE#] [#CM_TIME#] [#URL#]</small></dt><dd>[#BODY#]</dd></dl>', 'コンテンツレイアウト(コメント一覧)'),
+('output_head',      '0', 'HTMLヘッダ出力'),
+('head_view_detail', '<meta property="og:type" content="article" /><meta property="og:title" content="[#CT_TITLE#]" /><meta property="og:url" content="[#CT_URL#]" /><meta property="og:image" content="[#CT_IMAGE#]" /><meta property="og:description" content="[#CT_DESCRIPTION#]" /><meta property="og:site_name" content="[#SITE_NAME#]" />', 'HTMLヘッダ(詳細表示)'),
+('m:entry_view_count',      '3',         '記事表示数(携帯)'),
+('m:entry_view_order',      '1',         '記事表示順(携帯)'),
+('m:title_color',           '',         'タイトルの背景色'),
+('s:entry_view_count',        '10',        '記事表示数'),
+('s:entry_view_order',        '1',         '記事表示順'),
+('s:top_content',  '',          'トップ画面コンテンツ'),
+('s:auto_resize_image_max_size',  '280',      '画像の自動変換最大サイズ'),
+('s:jquery_view_style',       '1',      'jQueryMobile表示スタイル'),
+('s:use_title_list_image',       '1',      'タイトルリスト画像を使用'),
+('s:title_list_image',       '',      'タイトルリスト画像'),
+('s:layout_entry_single',   '<small>[#CT_AUTHOR#] [#CT_DATE#] [#CT_TIME#] [#BLOG_LINK#]</small>[#BODY#][#CATEGORY#][#LINKS#]', 'コンテンツレイアウト(記事詳細)'),
+('s:layout_entry_list',   '<small>[#CT_AUTHOR#] [#CT_DATE#] [#CT_TIME#] [#BLOG_LINK#]</small>[#BODY#][#CATEGORY#][#COMMENT_LINK#]', 'コンテンツレイアウト(記事一覧)'),
+('s:layout_comment_list', '[#AVATAR#]<dl><dt>[#TITLE#] <small>[#CM_AUTHOR#] [#CM_DATE#] [#CM_TIME#] [#URL#]</small></dt><dd>[#BODY#]</dd></dl>', 'コンテンツレイアウト(コメント一覧)'),
+('s:output_head',      '0', 'HTMLヘッダ出力'),
+('s:head_view_detail', '<meta property="og:type" content="article" /><meta property="og:title" content="[#CT_TITLE#]" /><meta property="og:url" content="[#CT_URL#]" /><meta property="og:image" content="[#CT_IMAGE#]" /><meta property="og:description" content="[#CT_DESCRIPTION#]" /><meta property="og:site_name" content="[#SITE_NAME#]" />', 'HTMLヘッダ(詳細表示)');
 
 -- BBS設定マスター
 INSERT INTO bbs_config (sf_id,                     sf_value,    sf_name,                        sf_index)
@@ -226,34 +235,38 @@ VALUES                 ('send_tmp_password', 'ja',           '仮パスワード
 -- テンプレート情報
 TRUNCATE TABLE _templates;
 INSERT INTO _templates
-(tm_id,                           tm_name,                         tm_type, tm_device_type, tm_mobile, tm_use_bootstrap, tm_available, tm_generator, tm_version) VALUES
-('_admin4',                       '_admin4',                       2,       0,              false,     true,             false,        '',           ''),
-('_system',                       '_system',                       1,       0,              false,     false,            false,        '',           ''),
-('_layout',                       '_layout',                       1,       0,              false,     false,            false,        '',           ''),
-('art41_sample1',                 'art41_sample1',                 2,       0,              false,     false,            true,         '',           ''),
-('art41_sample2',                 'art41_sample2',                 2,       0,              false,     false,            true,         '',           ''),
-('art42_sample3',                 'art42_sample3',                 2,       0,              false,     false,            true,         '',           ''),
-('art42_sample4',                 'art42_sample4',                 2,       0,              false,     false,            true,         '',           ''),
-('art42_sample5',                 'art42_sample5',                 2,       0,              false,     false,            true,         '',           ''),
-('themler_sample1',               'themler_sample1',               2,       0,              false,     false,            true,         'themler',    '1.0.39'),
-('bootstrap_yeti',                'bootstrap_yeti',                10,      0,              false,     true,             true,         '',           ''),
-('bootstrap_cerulean',            'bootstrap_cerulean',            10,      0,              false,     true,             true,         '',           ''),
-('bootstrap_united',              'bootstrap_united',              10,      0,              false,     true,             true,         '',           ''),
-('bootstrap_cerulean_head',       'bootstrap_cerulean_head',       10,      0,              false,     true,             true,         '',           ''),
-('m/default',                     'm/default',                     0,       1,              true,      false,            true,         '',           ''),
-('m/smallfont',                   'm/smallfont',                   0,       1,              true,      false,            true,         '',           ''),
-('s/default_simple',              's/default_simple',              1,       2,              false,     false,            true,         '',           ''),
-('s/default_jquery',              's/default_jquery',              1,       2,              false,     false,            true,         '',           ''),
-('s/default_jquery13',           's/default_jquery13',             1,       2,              false,     false,            true,         '',           ''),
-('s/art42_sample2',               's/art42_sample2',               1,       2,              false,     false,            true,         '',           '');
+(tm_id,                           tm_name,                         tm_type, tm_device_type, tm_mobile, tm_use_bootstrap, tm_available, tm_generator, tm_version, tm_info_url) VALUES
+('_admin',                       '_admin',                         2,       0,              false,     true,             false,        '',           '',         ''),
+('_system',                       '_system',                       1,       0,              false,     false,            false,        '',           '',         ''),
+('_layout',                       '_layout',                       1,       0,              false,     false,            false,        '',           '',         ''),
+('art41_sample1',                 'art41_sample1',                 2,       0,              false,     false,            true,         '',           '',         ''),
+('art41_sample2',                 'art41_sample2',                 2,       0,              false,     false,            true,         '',           '',         ''),
+('art42_sample3',                 'art42_sample3',                 2,       0,              false,     false,            true,         '',           '',         ''),
+('art42_sample4',                 'art42_sample4',                 2,       0,              false,     false,            true,         '',           '',         ''),
+('art42_sample5',                 'art42_sample5',                 2,       0,              false,     false,            true,         '',           '',         ''),
+('themler_sample0',               'themler_sample0',               2,       0,              false,     false,            true,         'themler',    '1.0.220',  ''),
+('bootstrap_yeti',                'bootstrap_yeti',                10,      0,              false,     true,             true,         '',           '',         ''),
+('bootstrap_cerulean',            'bootstrap_cerulean',            10,      0,              false,     true,             true,         '',           '',         ''),
+('bootstrap_united',              'bootstrap_united',              10,      0,              false,     true,             true,         '',           '',         ''),
+('bootstrap_cerulean_head',       'bootstrap_cerulean_head',       10,      0,              false,     true,             true,         '',           '',         ''),
+('bs_honoka3',                    'bs_honoka3',                    10,       0,             false,     true,             true,         '',           '',         'http://honokak.osaka/'),
+('bs_single_gray',                'bs_single_gray',                10,       0,             false,     true,             true,         '',           '',         'https://startbootstrap.com/template-overviews/grayscale/'),
+('bs_single_orange',              'bs_single_orange',              10,       0,             false,     true,             true,         '',           '',         'https://startbootstrap.com/template-overviews/creative/'),
+('wisteria',                      'wisteria',                      100,      0,             false,     false,            true,         '',           '',         'https://wpfriendship.com/'),
+('m/default',                     'm/default',                     0,       1,              true,      false,            true,         '',           '',         ''),
+('m/smallfont',                   'm/smallfont',                   0,       1,              true,      false,            true,         '',           '',         ''),
+('s/default_simple',              's/default_simple',              1,       2,              false,     false,            true,         '',           '',         ''),
+('s/default_jquery',              's/default_jquery',              1,       2,              false,     false,            true,         '',           '',         ''),
+('s/default_jquery13',           's/default_jquery13',             1,       2,              false,     false,            true,         '',           '',         ''),
+('s/art42_sample2',               's/art42_sample2',               1,       2,              false,     false,            true,         '',           '',         '');
 
 -- メニューIDマスター
 INSERT INTO _menu_id
 (mn_id,         mn_name,          mn_description, mn_device_type, mn_widget_id, mn_sort_order) VALUES
-('main_menu',   'メインメニュー(PC用)', '',             0,        '',      0),
-('sub_menu1',   'サブメニュー1(PC用)',  '',             0,        '',      1),
-('sub_menu2',   'サブメニュー2(PC用)',  '',             0,        '',      2),
-('sub_menu3',   'サブメニュー3(PC用)',  '',             0,        '',      3),
+('main_menu',   'メインメニュー', '',             0,        '',      0),
+('sub_menu1',   'サブメニュー1',  '',             0,        '',      1),
+('sub_menu2',   'サブメニュー2',  '',             0,        '',      2),
+('sub_menu3',   'サブメニュー3',  '',             0,        '',      3),
 ('m_main_menu', 'メインメニュー(携帯用)', '',             1,      '',        10),
 ('s_main_menu', 'メインメニュー(スマートフォン用)', '',             2,     '',         0);
 
