@@ -1,8 +1,8 @@
 /**
  * Japanese translation
  * @author Tomoaki Yoshida <info@yoshida-studio.jp>
- * @author Naoki Sawada <hypweb+elfinder@gmail.com>
- * @version 2018-05-22
+ * @author Naoki Sawada <hypweb@gmail.com>
+ * @version 2017-11-23
  */
 (function(root, factory) {
 	if (typeof define === 'function' && define.amd) {
@@ -14,7 +14,7 @@
 	}
 }(this, function(elFinder) {
 	elFinder.prototype.i18.ja = {
-		translator : 'Tomoaki Yoshida &lt;info@yoshida-studio.jp&gt;, Naoki Sawada &lt;hypweb+elfinder@gmail.com&gt;',
+		translator : 'Tomoaki Yoshida &lt;info@yoshida-studio.jp&gt;, Naoki Sawada &lt;hypweb@gmail.com&gt;',
 		language   : 'Japanese',
 		direction  : 'ltr',
 		dateFormat : 'Y/m/d h:i A', // Mar 13, 2012 05:27 PM
@@ -149,7 +149,7 @@
 			'cmdsort'      : 'ソート',
 			'cmdnetmount'  : 'ネットワークボリュームをマウント', // added 18.04.2012
 			'cmdnetunmount': 'アンマウント', // from v2.1 added 30.04.2012
-			'cmdplaces'    : 'よく使う項目へ', // added 28.12.2014
+			'cmdplaces'    : 'お気に入りへ', // added 28.12.2014
 			'cmdchmod'     : '属性変更', // from v2.1 added 20.6.2015
 			'cmdopendir'   : 'フォルダを開く', // from v2.1 added 13.1.2016
 			'cmdcolwidth'  : '列幅リセット', // from v2.1.13 added 12.06.2016
@@ -162,7 +162,6 @@
 			'cmdselectall' : 'すべて選択', // from v2.1.28 added 15.08.2017
 			'cmdselectnone': '選択解除', // from v2.1.28 added 15.08.2017
 			'cmdselectinvert': '選択を反転', // from v2.1.28 added 15.08.2017
-			'cmdopennew'   : '新しいウィンドウで開く', // from v2.1.38 added 3.4.2018
 
 			/*********************************** buttons ***********************************/
 			'btnClose'  : '閉じる',
@@ -290,8 +289,8 @@
 
 			/********************************** messages **********************************/
 			'confirmReq'      : '処理を実行しますか？',
-			'confirmRm'       : 'アイテムを完全に削除してもよろしいですか？<br/>この操作は取り消しできません！',
-			'confirmRepl'     : '古いファイルを新しいファイルで上書きしますか？ (フォルダが含まれている場合は統合されます。置き換える場合は「バックアップ」選択してください。)',
+			'confirmRm'       : 'アイテムを完全に削除してもよろしいですか？<br/>この操作は取り消せません！',
+			'confirmRepl'     : '古いアイテムを新しいアイテムで上書きしますか？',
 			'confirmRest'     : '既存のアイテムをごみ箱のアイテムで上書きしますか？', // fromv2.1.24 added 5.5.2017
 			'confirmConvUTF8' : 'UTF-8 以外の文字が含まれています。<br/>UTF-8  に変換しますか？<br/>変換後の保存でコンテンツは UTF-8 になります。', // from v2.1 added 08.04.2014
 			'confirmNonUTF8'  : 'このファイルの文字エンコーディングを判別できませんでした。編集するには一時的に UTF-8 に変換する必要があります。<br/>文字エンコーディングを指定してください。', // from v2.1.19 added 28.11.2016
@@ -314,16 +313,12 @@
 			'selectlfile'     : '最後のアイテムを選択',
 			'viewlist'        : 'リスト形式で表示',
 			'viewicons'       : 'アイコン形式で表示',
-			'viewSmall'       : '小アイコン', // from v2.1.39 added 22.5.2018
-			'viewMedium'      : '中アイコン', // from v2.1.39 added 22.5.2018
-			'viewLarge'       : '大アイコン', // from v2.1.39 added 22.5.2018
-			'viewExtraLarge'  : '特大アイコン', // from v2.1.39 added 22.5.2018
-			'places'          : 'よく使う項目',
+			'places'          : 'お気に入り',
 			'calc'            : '計算中',
 			'path'            : 'パス',
 			'aliasfor'        : 'エイリアス',
 			'locked'          : 'ロック',
-			'dim'             : '画素数',
+			'dim'             : 'サイズ',
 			'files'           : 'ファイル',
 			'folders'         : 'フォルダ',
 			'items'           : 'アイテム',
@@ -432,7 +427,7 @@
 			'folderToEmpty'   : 'フォルダ"$1"を空にします。', // from v2.1.25 added 22.6.2017
 			'filderIsEmpty'   : 'フォルダ"$1"にアイテムはありません。', // from v2.1.25 added 22.6.2017
 			'preference'      : '環境設定', // from v2.1.26 added 28.6.2017
-			'language'        : '言語', // from v2.1.26 added 28.6.2017
+			'language'        : '言語設定', // from v2.1.26 added 28.6.2017
 			'clearBrowserData': 'ブラウザに保存された設定を初期化する', // from v2.1.26 added 28.6.2017
 			'toolbarPref'     : 'ツールバー設定', // from v2.1.27 added 2.8.2017
 			'charsLeft'       : '... 残り $1 文字',  // from v2.1.29 added 30.8.2017
@@ -443,25 +438,6 @@
 			'selectAction'    : 'ファイル選択時の動作', // from v2.1.30 added 23.11.2017
 			'useStoredEditor' : '前回使用したエディターで開く', // from v2.1.30 added 23.11.2017
 			'selectinvert'    : '選択アイテムを反転', // from v2.1.30 added 25.11.2017
-			'renameMultiple'  : '選択した $1 個のアイテムを $2 のようにリネームしますか？<br/>この操作は取り消しできません！', // from v2.1.31 added 4.12.2017
-			'batchRename'     : '一括リネーム', // from v2.1.31 added 8.12.2017
-			'plusNumber'      : '+ 連番', // from v2.1.31 added 8.12.2017
-			'asPrefix'        : '先頭に追加', // from v2.1.31 added 8.12.2017
-			'asSuffix'        : '末尾に追加', // from v2.1.31 added 8.12.2017
-			'changeExtention' : '拡張子変更', // from v2.1.31 added 8.12.2017
-			'columnPref'      : '列項目設定(リストビュー)', // from v2.1.32 added 6.2.2018
-			'reflectOnImmediate' : '全ての変更は、直ちにアーカイブに反映されます。', // from v2.1.33 added 2.3.2018
-			'reflectOnUnmount'   : 'このボリュームをアンマウントするまで、変更は反映されません。', // from v2.1.33 added 2.3.2018
-			'unmountChildren' : 'このボリュームにマウントされている以下のボリュームもアンマウントされます。アンマウントしますか？', // from v2.1.33 added 5.3.2018
-			'selectionInfo'   : '選択情報', // from v2.1.33 added 7.3.2018
-			'hashChecker'     : 'ファイルハッシュを表示するアルゴリズム', // from v2.1.33 added 10.3.2018
-			'infoItems'       : '情報項目 (選択情報パネル)', // from v2.1.38 added 28.3.2018
-			'pressAgainToExit': 'もう一度押すと終了します。', // from v2.1.38 added 1.4.2018
-			'toolbar'         : 'ツールバー', // from v2.1.38 added 4.4.2018
-			'workspace'       : 'ワークスペース', // from v2.1.38 added 4.4.2018
-			'dialog'          : 'ダイアログ', // from v2.1.38 added 4.4.2018
-			'all'             : 'すべて', // from v2.1.38 added 4.4.2018
-			'iconSize'        : 'アイコンサイズ (アイコンビュー)', // form v2.1.39 added 7.5.2018
 
 			/********************************** mimetypes **********************************/
 			'kindUnknown'     : '不明',
