@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2015 Magic3 Project.
+ * @copyright  Copyright 2006-2017 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -210,7 +210,7 @@ function plugin_googlemaps3_action() {
 			break;
 		// maxContent用のレイアウトスタイルでページのbodyを出力
 		case 'showbody':
-			if (is_page($page)) {
+			if (WikiPage::isPage($page)) {
 				$body = convert_html(get_source($page));
 			} else {
 				if ($page == '') {
